@@ -9,4 +9,7 @@ class Transform :
         self.scale = Vector3(1,1,1)
 
     def __str__(self):
-        return "Transform(%s, %s, %s)" % (self.position, self.rotation, self.scale)
\ No newline at end of file
+        return "Transform(%s, %s, %s)" % (self.position, self.rotation, self.scale)
+
+    def isPointInside(self, point):
+        return self.position.x <= point.x <= self.position.x + self.scale.x and self.position.y <= point.y <= self.position.y + self.scale.y
\ No newline at end of file
